@@ -5,10 +5,10 @@ class TicketLogsController < ApplicationController
     ticket_logs.is_canceled = true
     ticket_logs.save
 
-    # TODO ticket_contorller のメソッドを呼び出すようにする
     @ticket = Ticket.find(ticket_logs.ticket_id)
-    @ticket.comment = ''
-    @ticket_logs = TicketLogs.where(ticket_id: @ticket.id)
+    create_ticket_logs()
+    @project_tickets = create_project_tickets(session[:project_id])
+    load_ticket_attributes()
     @show_comment_only = true
 
     respond_to do |format|
