@@ -7,6 +7,8 @@ class TicketsController < ApplicationController
     @ticket = Ticket.new(project_id: project_id, state_id: TicketOpened, priority_id: MinorPriority, workload_id: EasyWork)
     load_ticket_attributes()
 
+    session[:last_project_id] = @ticket.id
+
     respond_to do |format|
       format.html { redirect_to tickets_url }
       format.js
@@ -50,6 +52,7 @@ class TicketsController < ApplicationController
         session[:project_id] = params[:project_id]
       else
         session[:project_id] = nil
+        session[:last_project_id] = nil
       end
     end
     @project_tickets = create_project_tickets(session[:project_id])
@@ -72,7 +75,7 @@ class TicketsController < ApplicationController
     else
       create_ticket_logs()
       load_ticket_attributes()
-      @project_tickets = create_project_tickets(session[:project_id])
+      create_belong_project(session[:project_id])
       @show_comment_only = true
 
       # 既読フラグの削除
@@ -104,6 +107,8 @@ class TicketsController < ApplicationController
       respond_to do |format|
         if @ticket.update_attributes(params[:ticket])
 
+          session[:last_project_id] = @ticket.id
+
           create_ticket_logs()
           @project_tickets = create_project_tickets(session[:project_id])
           load_ticket_attributes()
